==> DateTime-Locale-1.16.tar.gz: DateTime-Locale-1.16/share/ak-GH.pl <==
{
  am_pm_abbreviated => [
    "AN",
    "EW"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y/M/d",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "ak-GH",
  date_format_full => "EEEE, y MMMM dd",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "yy/MM/dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Dwo",
    "Ben",
    "Wuk",
    "Yaw",
    "Fia",
    "Mem",
    "Kwe"
  ],
  day_format_narrow => [
    "D",
    "B",
    "W",
    "Y",
    "F",
    "M",
    "K"
  ],
  day_format_wide => [
    "Dwowda",
    "Benada",
    "Wukuda",
    "Yawda",
    "Fida",
    "Memeneda",
    "Kwesida"
  ],
  day_stand_alone_abbreviated => [
    "Dwo",
    "Ben",
    "Wuk",
    "Yaw",
    "Fia",
    "Mem",
    "Kwe"
  ],
  day_stand_alone_narrow => [
    "D",
    "B",
    "W",
    "Y",
    "F",
    "M",
    "K"
  ],
  day_stand_alone_wide => [
    "Dwowda",
    "Benada",
    "Wukuda",
    "Yawda",
    "Fida",
    "Memeneda",
    "Kwesida"
  ],
  era_abbreviated => [
    "AK",
    "KE"
  ],
  era_narrow => [
    "AK",
    "KE"
  ],
  era_wide => [
    "Ansa Kristo",
    "Kristo Ekyiri"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%Y/%m/%d",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%r",
  language => "Akan",
  month_format_abbreviated => [
    "S-\N{U+0186}",
    "K-\N{U+0186}",
    "E-\N{U+0186}",
    "E-O",
    "E-K",
    "O-A",
    "A-K",
    "D-\N{U+0186}",
    "F-\N{U+0190}",
    "\N{U+0186}-A",
    "\N{U+0186}-O",
    "M-\N{U+0186}"
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_format_wide => [
    "Sanda-\N{U+0186}p\N{U+025b}p\N{U+0254}n",
    "Kwakwar-\N{U+0186}gyefuo",
    "Eb\N{U+0254}w-\N{U+0186}benem",
    "Eb\N{U+0254}bira-Oforisuo",
    "Esusow Aketseaba-K\N{U+0254}t\N{U+0254}nimba",
    "Obirade-Ay\N{U+025b}wohomumu",
    "Ay\N{U+025b}woho-Kitawonsa",
    "Difuu-\N{U+0186}sandaa",
    "Fankwa-\N{U+0190}b\N{U+0254}",
    "\N{U+0186}b\N{U+025b}s\N{U+025b}-Ahinime",
    "\N{U+0186}ber\N{U+025b}f\N{U+025b}w-Obubuo",
    "Mumu-\N{U+0186}p\N{U+025b}nimba"
  ],
  month_stand_alone_abbreviated => [
    "S-\N{U+0186}",
    "K-\N{U+0186}",
    "E-\N{U+0186}",
    "E-O",
    "E-K",
    "O-A",
    "A-K",
    "D-\N{U+0186}",
    "F-\N{U+0190}",
    "\N{U+0186}-A",
    "\N{U+0186}-O",
    "M-\N{U+0186}"
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12
  ],
  month_stand_alone_wide => [
    "Sanda-\N{U+0186}p\N{U+025b}p\N{U+0254}n",
    "Kwakwar-\N{U+0186}gyefuo",
    "Eb\N{U+0254}w-\N{U+0186}benem",
    "Eb\N{U+0254}bira-Oforisuo",
    "Esusow Aketseaba-K\N{U+0254}t\N{U+0254}nimba",
    "Obirade-Ay\N{U+025b}wohomumu",
    "Ay\N{U+025b}woho-Kitawonsa",
    "Difuu-\N{U+0186}sandaa",
    "Fankwa-\N{U+0190}b\N{U+0254}",
    "\N{U+0186}b\N{U+025b}s\N{U+025b}-Ahinime",
    "\N{U+0186}ber\N{U+025b}f\N{U+025b}w-Obubuo",
    "Mumu-\N{U+0186}p\N{U+025b}nimba"
  ],
  name => "Akan Ghana",
  native_language => "Akan",
  native_name => "Akan Gaana",
  native_script => undef,
  native_territory => "Gaana",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4"
  ],
  script => undef,
  territory => "Ghana",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 31
}

==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/ak-GH.pl <==
{
  am_pm_abbreviated => [
    "AN",
    "EW",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E, M/d",
    MMM => "LLL",
    MMMEd => "E, MMM d",
    MMMMEd => "E, MMMM d",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "M/d",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "y MMM d",
    yMd => "y/M/d",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "ak-GH",
  date_format_full => "EEEE, y MMMM dd",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "yy/MM/dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Dwo",
    "Ben",
    "Wuk",
    "Yaw",
    "Fia",
    "Mem",
    "Kwe",
  ],
  day_format_narrow => [
    "D",
    "B",
    "W",
    "Y",
    "F",
    "M",
    "K",
  ],
  day_format_wide => [
    "Dwowda",
    "Benada",
    "Wukuda",
    "Yawda",
    "Fida",
    "Memeneda",
    "Kwesida",
  ],
  day_stand_alone_abbreviated => [
    "Dwo",
    "Ben",
    "Wuk",
    "Yaw",
    "Fia",
    "Mem",
    "Kwe",
  ],
  day_stand_alone_narrow => [
    "D",
    "B",
    "W",
    "Y",
    "F",
    "M",
    "K",
  ],
  day_stand_alone_wide => [
    "Dwowda",
    "Benada",
    "Wukuda",
    "Yawda",
    "Fida",
    "Memeneda",
    "Kwesida",
  ],
  era_abbreviated => [
    "AK",
    "KE",
  ],
  era_narrow => [
    "AK",
    "KE",
  ],
  era_wide => [
    "Ansa Kristo",
    "Kristo Ekyiri",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%Y/%m/%d",
  glibc_datetime_format => "%a %d %b %Y %T %Z",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%r",
  language => "Akan",
  month_format_abbreviated => [
    "S-\N{U+0186}",
    "K-\N{U+0186}",
    "E-\N{U+0186}",
    "E-O",
    "E-K",
    "O-A",
    "A-K",
    "D-\N{U+0186}",
    "F-\N{U+0190}",
    "\N{U+0186}-A",
    "\N{U+0186}-O",
    "M-\N{U+0186}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Sanda-\N{U+0186}p\N{U+025b}p\N{U+0254}n",
    "Kwakwar-\N{U+0186}gyefuo",
    "Eb\N{U+0254}w-\N{U+0186}benem",
    "Eb\N{U+0254}bira-Oforisuo",
    "Esusow Aketseaba-K\N{U+0254}t\N{U+0254}nimba",
    "Obirade-Ay\N{U+025b}wohomumu",
    "Ay\N{U+025b}woho-Kitawonsa",
    "Difuu-\N{U+0186}sandaa",
    "Fankwa-\N{U+0190}b\N{U+0254}",
    "\N{U+0186}b\N{U+025b}s\N{U+025b}-Ahinime",
    "\N{U+0186}ber\N{U+025b}f\N{U+025b}w-Obubuo",
    "Mumu-\N{U+0186}p\N{U+025b}nimba",
  ],
  month_stand_alone_abbreviated => [
    "S-\N{U+0186}",
    "K-\N{U+0186}",
    "E-\N{U+0186}",
    "E-O",
    "E-K",
    "O-A",
    "A-K",
    "D-\N{U+0186}",
    "F-\N{U+0190}",
    "\N{U+0186}-A",
    "\N{U+0186}-O",
    "M-\N{U+0186}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Sanda-\N{U+0186}p\N{U+025b}p\N{U+0254}n",
    "Kwakwar-\N{U+0186}gyefuo",
    "Eb\N{U+0254}w-\N{U+0186}benem",
    "Eb\N{U+0254}bira-Oforisuo",
    "Esusow Aketseaba-K\N{U+0254}t\N{U+0254}nimba",
    "Obirade-Ay\N{U+025b}wohomumu",
    "Ay\N{U+025b}woho-Kitawonsa",
    "Difuu-\N{U+0186}sandaa",
    "Fankwa-\N{U+0190}b\N{U+0254}",
    "\N{U+0186}b\N{U+025b}s\N{U+025b}-Ahinime",
    "\N{U+0186}ber\N{U+025b}f\N{U+025b}w-Obubuo",
    "Mumu-\N{U+0186}p\N{U+025b}nimba",
  ],
  name => "Akan Ghana",
  native_language => "Akan",
  native_name => "Akan Gaana",
  native_script => undef,
  native_territory => "Gaana",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => "Ghana",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 32,
}
